#! /usr/bin/env perl
################################################################################
#     The MOLCAS's platform compatibility checker                              #
#     Version 1.0                                                              #
#                                                                              #
#     Victor. P. Vysotskiy, 2014                                               #
#     Copyright: All rights are reserved                                       #
################################################################################
use Cwd;

#Define reference values
my ($x_ref,$y_ref) =(-0.058230, 0.0);
#Declare variables
my $specs;
my $rc,my $dir;
my @stdout,my @grad;

#Read platform
open(SPECS,'.platform') or die "Cannot open .platform specification: $!\n";
LINE:
while(my $line=<SPECS>) {
     chomp($line);
     next LINE if ($line=~/^\s*$/||$line=~/#/);
     $specs=$line;
}
close $SPECS;

#Extract data
$rc=system("tar -xf data.tar");
if ($rc!=0) {
   die "Cannot unpack the 'data.tar' archieve\n";
}

#Enter working directory
$dir=getcwd;
chdir("data") or die "cannot change: $!\n";

#Execute binary
chmod 0755, "test.exe";
@stdout=qx("$dir/data/test.exe");
$rc=$?>>8;
goto FINISH if($rc!=0);

#Analyze results
foreach my $line (@stdout) {
           $line=~s/^\s+|\s+$//g;
           @grad=split(/\s+/,$line) if($line=~/H1/);
}
$rc=1 if (($grad[1]!=$x_ref) || ($grad[2]!=$y_ref) || ($grad[2]!=$grad[3]));

#Inform an end-user
FINISH:
if($rc!=0) {
  print "Unfortunately, the choosen >>> $specs <<< binaries are not suitable for your platform. Please try another one!\n ";
} else {
  print "Congratulations! Your platform is suitable for the choosen >>> $specs <<< binary distribution!\n ";
}
#Clean up
chdir($dir) or die "Cannot change the directory: $!\n";
cleanup("data");

sub cleanup {
my $dir = shift;
local *DIR;

opendir DIR, $dir or die "Cannot clean up $dir, please do it manually: rm -rf $dir ";
for (readdir DIR) {
     next if /^\.{1,2}$/;
     my $path = "$dir/$_";
     unlink $path if -f $path;
     cleanup($path) if -d $path;
}

closedir DIR;
rmdir $dir or print "Error - $!";
}
